@@ -23,26 +23,59 @@ specified location.
 """
 
 import argparse
+import os
 
 from .utk_face.model_vgg import vgg_utk_face
 from .kws.model_ds_cnn import ds_cnn_kws
 from .modelnet40.model_pointnet_plus import pointnet_plus_modelnet40
 from .imagenet.model_mobilenet import mobilenet_imagenet
-from .imagenet.model_vgg import vgg_imagenet
 from .imagenet.model_akidanet import akidanet_imagenet
 from .imagenet.model_akidanet_edge import akidanet_edge_imagenet
 from .imagenet.model_akidanet18 import akidanet18_imagenet
-from .imagenet.model_mobilenet_edge import mobilenet_edge_imagenet
 from .detection.model_yolo import yolo_base
 from .dvs.model_convtiny_handy import convtiny_dvs_handy
 from .dvs.model_convtiny_gesture import convtiny_dvs_gesture
-from .cwru.model_convtiny import convtiny_cwru
 from .mnist.model_gxnor import gxnor_mnist
 from .transformers.model_vit import vit_ti16, bc_vit_ti16
 from .transformers.model_deit import deit_ti16, bc_deit_ti16
 from .portrait128.model_akida_unet import akida_unet_portrait128
 from .centernet.model_centernet import centernet_base
 from .macs import display_macs
+from .utils import load_weights, save_weights, load_model
+from .unfuse_sepconv_layers import unfuse_sepconv2d
+
+
+def save_model_weights(model_path, weights_path):
+    """ CLI entry point to save the model weights in an npz file.
+
+    Args:
+        model_path (str): Path to the model to extract the weights from.
+        weights_path (str): Path to save the npz file.
+            Defaults to <model_path>.npz.
+    """
+    # Build name for weights file
+    if weights_path is None:
+        model_name = os.path.splitext(model_path)[0]
+        weights_path = f"{model_name}.npz"
+
+    # Load the model and save its weights
+    model = load_model(model_path)
+    save_weights(model, weights_path)
+    print(f"Saved model weights to {weights_path}.")
+
+
+def load_model_weights(model_path, weights_path):
+    """ CLI entry point to apply weights to a model from an npz file.
+
+    Args:
+        model_path (str): Path to the model on which apply the weights.
+        weights_path (str): Path to load the npz file.
+    """
+    # Update the model weights with the npz file
+    model = load_model(model_path)
+    load_weights(model, weights_path)
+    model.save(model_path, include_optimizer=False)
+    print(f"Saved model with new weights to {model_path}.")
 
 
 def add_transformers_args(parser, add_customs=False, default_norm='LN', default_act='GeLU'):
@@ -149,14 +182,6 @@ def main():
                                help="A MobileNet V1 model for akida")
     add_common_args(mb_parser, default_classes=1000, default_alpha=1.0, default_img_size=224)
 
-    vgg_parser = csp.add_parser("vgg_imagenet", help="A VGG model for akida")
-    add_common_args(vgg_parser, default_classes=1000)
-
-    mbe_parser = csp.add_parser("mobilenet_imagenet_edge",
-                                help="A MobileNet V1 model modified for akida \
-                                edge learning")
-    add_common_args(mbe_parser, default_classes=1000, bw_required=True)
-
     an_parser = csp.add_parser("akidanet_imagenet", help="An AkidaNet model")
     add_common_args(an_parser, default_classes=1000, default_img_size=224, default_alpha=1.0)
 
@@ -186,7 +211,6 @@ def main():
                            default=5,
                            help="The number of anchor boxes")
 
-    csp.add_parser("convtiny_cwru", help="A Convtiny CWRU model for akida")
     csp.add_parser("gxnor_mnist", help="A GXNOR MNIST model for akida")
 
     akun_parser = csp.add_parser("akida_unet_portrait128",
@@ -224,6 +248,26 @@ def main():
     macs_parser.add_argument("-m", "--model", type=str)
     macs_parser.add_argument("-v", "--verbose", action="store_true")
 
+    unfuse_parser = sp.add_parser(
+        "unfuse", help="Unfuse SeparableConv2D layers of a Keras model")
+    unfuse_parser.add_argument("-m", "--model", type=str, required=True, help="Model to unfuse.")
+
+    # Save weights arguments
+    w_parser = sp.add_parser(
+        "save_weights", help="Store model's weights in an npz.")
+    w_parser.add_argument("-m", "--model", type=str, required=True,
+                          help="Model to extract weights from.")
+    w_parser.add_argument("-w", "--weights_path", type=str,
+                          help="Npz file that contains the saved weights.")
+
+    # Load weights arguments
+    w_parser = sp.add_parser(
+        "load_weights", help="Apply weights to a model from an npz file.")
+    w_parser.add_argument("-m", "--model", type=str, required=True,
+                          help="Model to apply the weights.")
+    w_parser.add_argument("-w", "--weights_path", type=str, required=True,
+                          help="Npz file that contains the weights to apply.")
+
     args = parser.parse_args()
     if args.action == "create":
         # Instantiate the wished model
@@ -243,11 +287,6 @@ def main():
             model = mobilenet_imagenet(input_shape,
                                        alpha=args.alpha,
                                        classes=args.classes)
-        elif args.model == "vgg_imagenet":
-            model = vgg_imagenet(classes=args.classes)
-        elif args.model == "mobilenet_imagenet_edge":
-            model = mobilenet_edge_imagenet(base_model=args.base_weights,
-                                            classes=args.classes)
         elif args.model == "akidanet_imagenet":
             input_shape = (args.image_size, args.image_size, 3)
             model = akidanet_imagenet(input_shape,
@@ -270,8 +309,6 @@ def main():
                                    classes=args.classes, alpha=args.alpha)
             if args.base_weights is not None:
                 model.load_weights(args.base_weights, by_name=True)
-        elif args.model == "convtiny_cwru":
-            model = convtiny_cwru()
         elif args.model == "gxnor_mnist":
             model = gxnor_mnist()
         elif args.model == "akida_unet_portrait128":
@@ -309,7 +346,7 @@ def main():
         # valid model types
         model_path = args.save_model
         if model_path is None:
-            models_by_name = ("mobilenet_imagenet", "mobilenet_imagenet_edge", "centernet")
+            models_by_name = ("mobilenet_imagenet", "centernet")
             model_path = f"{model.name}.h5" if args.model in models_by_name else f"{args.model}.h5"
 
         # If needed, add the extension
@@ -320,3 +357,23 @@ def main():
 
     elif args.action == "macs":
         display_macs(args.model, args.verbose)
+    elif args.action == "save_weights":
+        save_model_weights(
+            model_path=args.model,
+            weights_path=args.weights_path,
+        )
+    elif args.action == "load_weights":
+        load_model_weights(
+            model_path=args.model,
+            weights_path=args.weights_path,
+        )
+    elif args.action == "unfuse":
+        model = load_model(args.model)
+        unfused_model = unfuse_sepconv2d(model)
+        # strip file extension from model path
+        model_path = os.path.splitext(args.model)[0]
+        # Write new path for unfused model
+        model_path += "_unfused.h5"
+        # Save unfused model
+        unfused_model.save(model_path, include_optimizer=False)
+        print(f"{model.name} has been unfused and saved under {model_path}.")
