@@ -134,7 +134,7 @@ def yolo_widerface_pretrained():
 
     model_name = 'yolo_akidanet_widerface_iq8_wq4_aq4.h5'
     file_hash = 'd55744cbfbbe1131aa26015f38d99f1df7026347bae8f66683259e366e7b6e03'
-    model_path = fetch_file('http://data.brainchip.com/models/yolo/' + model_name,
+    model_path = fetch_file('http://data.brainchip.com/models/AkidaV1/yolo/' + model_name,
                             fname=model_name,
                             file_hash=file_hash,
                             cache_subdir='models')
@@ -163,7 +163,7 @@ def yolo_voc_pretrained():
 
     model_name = 'yolo_akidanet_voc_iq8_wq4_aq4.h5'
     file_hash = 'e65b0b6bd4b08c2796c3bbea89343748195e29e240ce28e70489c53d06ca69d9'
-    model_path = fetch_file('http://data.brainchip.com/models/yolo/' + model_name,
+    model_path = fetch_file('http://data.brainchip.com/models/AkidaV1/yolo/' + model_name,
                             fname=model_name,
                             file_hash=file_hash,
                             cache_subdir='models')
