@@ -32,7 +32,7 @@ from ..utils import fetch_file
 # if care isn't taken to ensure enough info capacity
 NUM_SPIKING_NEURONS = 256
 
-BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/convtiny/'
+BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/AkidaV1/convtiny/'
 
 
 def convtiny_dvs_gesture(input_shape=(64, 64, 10),
