@@ -287,6 +287,7 @@ def _filter_magnitudes(layer):
 def smallest_filters(layer, pruning_rate):
     """Returns indices of the smallest filters to prune, based on the rate
     of filters to prune.
+
     Pruning rate must be a value between 0 and 1. For instance, 0.3 means
     that 30% of the filters will be pruned. The function then returns the
     indices of the 30% smallest filters in this layer.
@@ -296,7 +297,7 @@ def smallest_filters(layer, pruning_rate):
         pruning_rate (float): the pruning rate (between 0 and 1).
 
     Returns:
-        `:obj:np.ndarray`: the indices of the filters to prune.
+        np.ndarray: the indices of the filters to prune.
     """
     l1_norms = _filter_magnitudes(layer)
     indices_sorted = np.argsort(l1_norms)
