@@ -34,7 +34,7 @@ from keras.callbacks import LearningRateScheduler
 from keras import Sequential
 from keras.optimizers import SGD, Adam
 from tensorflow_addons.optimizers import LAMB
-from keras.layers import Input, Activation
+from keras.layers import Input
 from keras.models import clone_model
 
 import akida
@@ -43,7 +43,7 @@ from quantizeml.layers import AddPositionEmbs, ClassToken
 
 from .preprocessing import preprocess_image, DATA_AUGMENTATION
 from ..training import (get_training_parser, calibrate_model, freeze_model_before,
-                        print_history_stats, RestoreBest)
+                        print_history_stats, RestoreBest, save_model)
 from ..calibrable import calibration_required
 from ..transformers.model_vit import apply_embedding_weights
 from ..distiller import DeitDistiller
@@ -143,13 +143,6 @@ def compile_model(model, optimizer="SGD", distiller_type="none"):
                       distiller_type=distiller_type)
         return True
 
-    # Preserve legacy behavior where models have a softmax activation at the end
-    if isinstance(model.layers[-2], Activation):
-        model.compile(optimizer=_get_optim(optimizer),
-                      loss='sparse_categorical_crossentropy',
-                      metrics=['accuracy', 'sparse_top_k_categorical_accuracy'])
-        return False
-
     model.compile(optimizer=_get_optim(optimizer),
                   loss=keras.losses.CategoricalCrossentropy(from_logits=True),
                   metrics=['accuracy', 'top_k_categorical_accuracy'])
@@ -189,7 +182,7 @@ def evaluate(model, val_dataset, batch_size, num_samples, val_steps):
         while cur_samples < num_samples:
             x, y = next(it)
             y_ak = model.predict_classes(x.astype(np.uint8))
-            correct_preds += np.sum(y_ak == y.flatten())
+            correct_preds += np.sum(y_ak == np.argmax(y, -1))
             cur_samples += y_ak.shape[0]
             if cur_samples % log_samples == 0 and cur_samples < num_samples:
                 # Log current accuracy
@@ -574,11 +567,7 @@ def main():
               learning_rate=learning_rate,
               initial_epoch=args.initial_epoch,
               lr_policy=args.lr_policy)
-
-        # Save model in Keras format (h5)
-        if args.savemodel:
-            model.save(args.savemodel, include_optimizer=False)
-            print(f"Trained model saved as {args.savemodel}")
+        save_model(model, args.model, args.savemodel, args.action)
 
     elif args.action == 'eval':
         # Evaluate model accuracy
@@ -589,11 +578,7 @@ def main():
     elif args.action == 'rescale':
         # Rescale model
         m = rescale(model, args.input_size)
-
-        # Save model in Keras format (h5)
-        if args.savemodel:
-            m.save(args.savemodel, include_optimizer=False)
-            print(f"Rescaled model saved as {args.savemodel}")
+        save_model(m, args.model, args.savemodel, args.action)
 
     elif args.action == "calibrate":
         # Calibrate model
@@ -602,11 +587,7 @@ def main():
                                                      im_size, args.batch_size,
                                                      False, one_hot=one_hot)
         calibrate_model(model, train_ds, args.num_samples, args.batch_size, args.epochs)
-
-        # Save model in Keras format (h5)
-        if args.savemodel:
-            model.save(args.savemodel, include_optimizer=False)
-            print(f"Calibrated model saved as {args.savemodel}")
+        save_model(model, args.model, args.savemodel, args.action)
 
 
 if __name__ == "__main__":
