@@ -23,15 +23,15 @@ architectures. It can be used for multiple use cases through transfer learning.
 """
 
 from keras import Model, regularizers
-from keras.layers import (Input, Reshape, Dropout, Activation, Rescaling)
+from keras.layers import Input, Dropout, Rescaling
 
 from cnn2snn import quantize, load_quantized_model
 
 from .imagenet_utils import obtain_input_shape
-from ..layer_blocks import conv_block, separable_conv_block
+from ..layer_blocks import conv_block, separable_conv_block, dense_block
 from ..utils import fetch_file
 
-BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/akidanet/'
+BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/AkidaV1/akidanet/'
 
 
 def akidanet_imagenet(input_shape=None,
@@ -279,23 +279,13 @@ def akidanet_imagenet(input_shape=None,
                              pointwise_regularizer=weight_regularizer)
 
     if include_top:
-        shape = (1, 1, int(1024 * alpha))
-
-        x = Reshape(shape, name='reshape_1')(x)
         x = Dropout(1e-3, name='dropout')(x)
-
-        x = separable_conv_block(x,
-                                 filters=classes,
-                                 name='separable_14',
-                                 kernel_size=(3, 3),
-                                 padding='same',
-                                 use_bias=False,
-                                 add_batchnorm=False,
-                                 add_activation=False,
-                                 pointwise_regularizer=weight_regularizer)
-        act_function = 'softmax' if classes > 1 else 'sigmoid'
-        x = Activation(act_function, name=f'act_{act_function}')(x)
-        x = Reshape((classes,), name='reshape_2')(x)
+        x = dense_block(x,
+                        classes,
+                        name='classifier',
+                        add_batchnorm=False,
+                        add_activation=False,
+                        kernel_regularizer=weight_regularizer)
 
     # Create model.
     model = Model(img_input,
@@ -325,63 +315,13 @@ def akidanet_imagenet_pretrained(alpha=1.0):
     """
     if alpha == 1.0:
         model_name = 'akidanet_imagenet_224_iq8_wq4_aq4.h5'
-        file_hash = '88e2e77e9c1379f2972f269f04656fc28d29e4971cc50dc2c75b49c722a8d581'
+        file_hash = '359e0ff05abbb26fe215830ca467ef40761767c0d77f8c743c6d6e4fffa7a925'
     elif alpha == 0.5:
         model_name = 'akidanet_imagenet_224_alpha_50_iq8_wq4_aq4.h5'
-        file_hash = '609dd98260f9304b7a9f0efa6553d0b9789b8cf858dbaa962756028715ee238f'
+        file_hash = '1d9493115d43625f2644f8265f71b8487c4019047fc331e892a233a3d6520371'
     elif alpha == 0.25:
         model_name = 'akidanet_imagenet_224_alpha_25_iq8_wq4_aq4.h5'
-        file_hash = '4760ffd387fe08ce9aa28a8dcd30cf8c23af151855d7a07397c3dd3c0ad43fcc'
-    else:
-        raise ValueError(
-            f"Requested model with alpha={alpha} is not available.")
-
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def akidanet_cats_vs_dogs_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    Cats vs.Dogs dataset.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_cats_vs_dogs_iq8_wq4_aq4_lwq_float.h5'
-    file_hash = 'c3483a261bcbcdb5175c43bcf839bcd9124e2fb81c0a84ec4d84702f111313b2'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def akidanet_imagenette_pretrained(alpha=1.0):
-    """
-    Helper method to retrieve a `akidanet_imagenet` model that was trained on
-    Imagenette dataset.
-
-    Args:
-        alpha (float, optional): width of the model, allowed values in [0.25,
-            0.5, 1]. Defaults to 1.0.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-    """
-    if alpha == 1.0:
-        model_name = 'akidanet_imagenette_224_iq8_wq4_aq4.h5'
-        file_hash = 'e48c3083f529d3cb91db090e8bfb9b2669dfce2b4407391ca848f005e656b4d8'
-    elif alpha == 0.5:
-        model_name = 'akidanet_imagenette_224_alpha_50_iq8_wq4_aq4.h5'
-        file_hash = 'a96cf3c49dec0c3d4d6db6e964748402faa16565e174e785128dcdec3555a830'
-    elif alpha == 0.25:
-        model_name = 'akidanet_imagenette_224_alpha_25_iq8_wq4_aq4.h5'
-        file_hash = '90e2eb651cf490129c1e619017dd47b1e87367aeea0a5401da62782d8f33c19f'
+        file_hash = '9146d6228d859d8b8db1c1b7a795471096e5a49ee4ff5656eabc6be749d42f5e'
     else:
         raise ValueError(
             f"Requested model with alpha={alpha} is not available.")
@@ -411,101 +351,6 @@ def akidanet_faceidentification_pretrained():
     return load_quantized_model(model_path)
 
 
-def akidanet_faceverification_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    CASIA Webface dataset and optimized with ArcFace that can perform face
-    verification on LFW.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_faceverification_iq8_wq4_aq4.h5'
-    file_hash = 'b52cba91acbda689587f103bfd28dff59c6b8cd10b4b1bbb09f0df96b37dabfb'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def akidanet_melanoma_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    SIIM-ISIC Melanoma Classification dataset.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_melanoma_iq8_wq4_aq4.h5'
-    file_hash = '98f5bbdd35089ef0ade17d3e1d7f80ed31f28bdf736ef5d4c4519adac813ac69'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def akidanet_odir5k_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    ODIR-5K dataset.
-
-    The model focuses on the following classes that are a part of the original
-    dataset: normal, cataract, AMD (age related macular degeneration) and
-    pathological myopia.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_odir5k_iq8_wq4_aq4.h5'
-    file_hash = 'f7bd4b8a7d808541e4dcd7e078a3e9fada83e756b56513af89abb5c453c216c3'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def akidanet_retinal_oct_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    retinal OCT dataset.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_retinal_oct_iq8_wq4_aq4.h5'
-    file_hash = 'a5de3d3b6d5545870de2275ea59df7940e22f9eec863f4302e8600177ece9b58'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def akidanet_ecg_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    ECG classification Physionet2017 dataset.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_ecg_iq8_wq4_aq4.h5'
-    file_hash = 'a124f4a9ab8a02bab73714e457ef470a542afadf6ab4cd6cc52f10e6bee025e9'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
 def akidanet_plantvillage_pretrained():
     """
     Helper method to retrieve an `akidanet_imagenet` model that was trained on
@@ -524,26 +369,6 @@ def akidanet_plantvillage_pretrained():
     return load_quantized_model(model_path)
 
 
-def akidanet_cifar10_pretrained():
-    """
-    Helper method to retrieve an `akidanet_imagenet` model that was trained on
-    CIFAR-10 dataset. Since CIFAR-10 images have a 32x32 size, they need to be
-    resized to match akidanet input layer. This can be done by calling the
-    'resize_image' function available under akida_models.cifar10.preprocessing.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'akidanet_cifar10_iq8_wq4_aq4.h5'
-    file_hash = 'cf5bba0e0704af3ef9752910e8a0dfddaf96666fd4d724b2f31a8733f1e153c3'
-    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
-                            fname=model_name,
-                            file_hash=file_hash,
-                            cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
 def akidanet_vww_pretrained():
     """
     Helper method to retrieve an `akidanet_imagenet` model that was trained on
@@ -554,7 +379,7 @@ def akidanet_vww_pretrained():
 
     """
     model_name = 'akidanet_vww_iq8_wq4_aq4.h5'
-    file_hash = 'b962e022071fcc77cb9403e1343341f3c160c870ba7d1f4a5011da67e4d33e66'
+    file_hash = 'cd130d90ed736447b6244dc1228e708b9dab20af0d2bf57b9a49df4362467ea8'
     model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
                             fname=model_name,
                             file_hash=file_hash,
