@@ -28,15 +28,15 @@ compatible for Akida with:
 """
 
 from keras import Model, regularizers
-from keras.layers import (Input, Reshape, Dropout, Activation, Rescaling)
+from keras.layers import Input, Dropout, Rescaling
 
 from cnn2snn import load_quantized_model, quantize
 
 from .imagenet_utils import obtain_input_shape
-from ..layer_blocks import conv_block, separable_conv_block
+from ..layer_blocks import conv_block, separable_conv_block, dense_block
 from ..utils import fetch_file
 
-BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/mobilenet/'
+BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/AkidaV1/mobilenet/'
 
 
 def mobilenet_imagenet(input_shape=None,
@@ -45,7 +45,7 @@ def mobilenet_imagenet(input_shape=None,
                        include_top=True,
                        pooling=None,
                        classes=1000,
-                       use_stride2=False,
+                       use_stride2=True,
                        weight_quantization=0,
                        activ_quantization=0,
                        input_weight_quantization=None,
@@ -78,7 +78,7 @@ def mobilenet_imagenet(input_shape=None,
         classes (int, optional): optional number of classes to classify images
             into, only to be specified if `include_top` is `True`. Defaults to 1000.
         use_stride2 (bool, optional): replace max pooling operations by stride 2
-            convolutions in layers separable 2, 4, 6 and 12. Defaults to False.
+            convolutions in layers separable 2, 4, 6 and 12. Defaults to True.
         weight_quantization (int, optional): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -304,23 +304,14 @@ def mobilenet_imagenet(input_shape=None,
                              pointwise_regularizer=weight_regularizer)
 
     if include_top:
-        shape = (1, 1, int(1024 * alpha))
-
-        x = Reshape(shape, name='reshape_1')(x)
         x = Dropout(dropout, name='dropout')(x)
-
-        x = separable_conv_block(x,
-                                 filters=classes,
-                                 name='separable_14',
-                                 kernel_size=(3, 3),
-                                 padding='same',
-                                 use_bias=False,
-                                 add_batchnorm=False,
-                                 add_activation=False,
-                                 pointwise_regularizer=weight_regularizer)
-        act_function = 'softmax' if classes > 1 else 'sigmoid'
-        x = Activation(act_function, name=f'act_{act_function}')(x)
-        x = Reshape((classes,), name='reshape_2')(x)
+        x = dense_block(x,
+                        units=classes,
+                        name='classifier',
+                        use_bias=False,
+                        add_batchnorm=False,
+                        add_activation=False,
+                        kernel_regularizer=weight_regularizer)
 
     # Create model.
     model = Model(img_input,
@@ -348,13 +339,13 @@ def mobilenet_imagenet_pretrained(alpha=1.0):
     """
     if alpha == 1.0:
         model_name = 'mobilenet_imagenet_224_iq8_wq4_aq4.h5'
-        file_hash = '242a5d6e155f9677e4a295d6c0b092061ab442bd2c51898663d818b706fc2c34'
+        file_hash = '4e63ea329b3f2f773a0b9d6fef4e449639fda89d17e48bb7132b6ad86585c867'
     elif alpha == 0.5:
         model_name = 'mobilenet_imagenet_224_alpha_50_iq8_wq4_aq4.h5'
-        file_hash = 'aa8fec3c21455dbb16dc86063ea07fcba792dcdaf8293c58db42dc379c78afc1'
+        file_hash = '133204fe087b728adc975a3bd71c275b5dbec8974555e2fa3a6ef8727cc5c9ac'
     elif alpha == 0.25:
         model_name = 'mobilenet_imagenet_224_alpha_25_iq8_wq4_aq4.h5'
-        file_hash = '2765b8b24e880f593dbb18d73e8750e51a3dfc8f38f2978d9d6679e3f970466a'
+        file_hash = '35ad51e662ed04b68978865ccb1c16bf024fa013146488b2a9c18c80d1efab29'
     else:
         raise ValueError(
             f"Requested model with alpha={alpha} is not available.")
