@@ -26,8 +26,8 @@ from keras.utils.np_utils import to_categorical
 from cnn2snn import load_quantized_model, quantize_layer, convert
 
 from ..cyclic_lr import CyclicLR
-from ..training import (get_training_parser, calibrate_model, compile_model, evaluate_model,
-                        print_history_stats, RestoreBest)
+from ..training import (get_training_parser, compile_model, evaluate_model, print_history_stats,
+                        RestoreBest, save_model)
 from ..utils import fetch_file
 
 
@@ -97,7 +97,7 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
 def main():
     """ Entry point for script and CLI usage.
     """
-    parsers = get_training_parser(calibrate=True, batch_size=100, global_batch_size=False)
+    parsers = get_training_parser(batch_size=100, global_batch_size=False)
 
     train_parser = parsers[1]
     train_parser.add_argument("-laq",
@@ -121,16 +121,13 @@ def main():
     # Load data
     x_train, y_train, x_val, y_val = get_data()
 
+    # Disable QuantizeML assertions
+    os.environ["ASSERT_ENABLED"] = "0"
+
     # Train model
     if args.action == "train":
-        train_model(model, x_train, y_train, x_val, y_val, args.batch_size,
-                    args.epochs)
-
-        # Save model in Keras format (h5)
-        if args.savemodel:
-            model.save(args.savemodel, include_optimizer=False)
-            print(f"Trained model saved as {args.savemodel}")
-
+        train_model(model, x_train, y_train, x_val, y_val, args.batch_size, args.epochs)
+        save_model(model, args.model, args.savemodel, args.action)
     elif args.action == "eval":
         # Evaluate model accuracy
         if args.akida:
@@ -140,18 +137,6 @@ def main():
         else:
             evaluate_model(model, x_val, y=to_categorical(y_val))
 
-    elif args.action == "calibrate":
-        # Calibrate model
-        calibrate_model(model,
-                        x_train,
-                        num_samples=args.num_samples,
-                        batch_size=args.batch_size,
-                        epochs=args.epochs)
-        # Save model in Keras format (h5)
-        if args.savemodel:
-            model.save(args.savemodel, include_optimizer=False)
-            print(f"Calibrated model saved as {args.savemodel}")
-
 
 if __name__ == "__main__":
     main()
