@@ -26,7 +26,7 @@ from cnn2snn import load_quantized_model, quantize
 from ..layer_blocks import conv_block, separable_conv_block, dense_block
 from ..utils import fetch_file
 
-BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/ds_cnn/'
+BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/AkidaV1/ds_cnn/'
 
 
 def ds_cnn_kws(input_shape=(49, 10, 1),
