@@ -19,14 +19,14 @@ Layers blocks definitions.
 """
 from functools import partial
 
-from keras.layers import (BatchNormalization, ReLU, Conv2D, SeparableConv2D, Dense, MaxPool2D,
-                          AvgPool2D, GlobalAvgPool2D, LayerNormalization, Dropout, Add,
+from keras.layers import (BatchNormalization, ReLU, Conv2D, DepthwiseConv2D, SeparableConv2D, Dense,
+                          MaxPool2D, GlobalAvgPool2D, LayerNormalization, Dropout, Add,
                           Conv2DTranspose, Reshape)
 from keras.activations import swish
 from keras.initializers import TruncatedNormal
 from tensorflow_addons.layers import GELU, GroupNormalization
 
-from quantizeml.layers import (Attention, LayerMadNormalization, SeparableConv2DTranspose,
+from quantizeml.layers import (Attention, LayerMadNormalization, DepthwiseConv2DTranspose,
                                ExtractToken)
 
 
@@ -38,8 +38,7 @@ def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
 
     Args:
         x (tf.Tensor): the input tensor
-        pooling_type (str): type of pooling among the following: 'max',
-            'avg' or 'global_avg'.
+        pooling_type (str): type of pooling among the following: 'max' or 'global_avg'.
         pool_size (int or tuple of 2 integers): factors by which to
             downscale (vertical, horizontal). (2, 2) will halve the input in
             both spatial dimension. If only one integer is specified, the same
@@ -54,19 +53,16 @@ def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
         return MaxPool2D(pool_size=pool_size,
                          padding=padding,
                          name=layer_base_name + '/maxpool')(x)
-    if pooling_type == 'avg':
-        return AvgPool2D(pool_size=pool_size,
-                         padding=padding,
-                         name=layer_base_name + '/avgpool')(x)
     if pooling_type == 'global_avg':
         return GlobalAvgPool2D(name=layer_base_name + '/global_avg')(x)
-    raise ValueError("'pooling_type' argument must be 'max', 'avg' or 'global_avg'.")
+    raise ValueError("'pooling_type' argument must be 'max' or 'global_avg'.")
 
 
 def conv_block(inputs,
                filters,
                kernel_size,
                pooling=None,
+               post_relu_gap=False,
                pool_size=(2, 2),
                add_batchnorm=False,
                add_activation=True,
@@ -82,9 +78,10 @@ def conv_block(inputs,
             height and width of the 2D convolution kernel.
             Can be a single integer to specify the same value for
             all spatial dimensions.
-        pooling (str): add a pooling layer of type 'pooling' among the
-            values 'max', 'avg', 'global_max' or 'global_avg', with pooling
-            size set to pool_size. If 'None', no pooling will be added.
+        pooling (str): add a pooling layer of type 'pooling' among the values 'max' or 'global_avg',
+            with pooling size set to pool_size. If 'None', no pooling will be added.
+        post_relu_gap (bool): when pooling is 'global_avg', indicates if the pooling comes before or
+            after ReLU activation. Defaults to False.
         pool_size (int or tuple of 2 integers): factors by which to
             downscale (vertical, horizontal). (2, 2) will halve the input in
             both spatial dimension. If only one integer is specified, the same
@@ -105,9 +102,8 @@ def conv_block(inputs,
     conv_layer = Conv2D(filters, kernel_size, **kwargs)
     x = conv_layer(inputs)
 
-    if pooling:
-        x = _add_pooling_layer(x, pooling, pool_size, conv_layer.padding,
-                               conv_layer.name)
+    if pooling == 'max' or (pooling == 'global_avg' and not post_relu_gap):
+        x = _add_pooling_layer(x, pooling, pool_size, conv_layer.padding, conv_layer.name)
 
     if add_batchnorm:
         x = BatchNormalization(name=conv_layer.name + '/BN')(x)
@@ -115,17 +111,26 @@ def conv_block(inputs,
     if add_activation:
         x = ReLU(6.0, name=conv_layer.name + '/relu')(x)
 
+    if post_relu_gap and pooling == 'global_avg':
+        x = _add_pooling_layer(x, pooling, pool_size, conv_layer.padding, conv_layer.name)
     return x
 
 
 def separable_conv_block(inputs,
                          filters,
                          kernel_size,
+                         strides=1,
+                         padding="same",
+                         use_bias=True,
                          pooling=None,
+                         post_relu_gap=False,
                          pool_size=(2, 2),
                          add_batchnorm=False,
                          add_activation=True,
-                         **kwargs):
+                         fused=True,
+                         name=None,
+                         kernel_initializer='glorot_uniform',
+                         pointwise_regularizer=None):
     """Adds a separable convolutional layer with optional layers in the
     following order: global average pooling, max pooling, batch normalization,
     activation.
@@ -137,43 +142,74 @@ def separable_conv_block(inputs,
         kernel_size (int or tuple of 2 integers): specifying the
             height and width of the 2D convolution window. Can be a single
             integer to specify the same value for all spatial dimensions.
-        pooling (str): add a pooling layer of type 'pooling' among the
-            values 'max', 'avg', 'global_max' or 'global_avg', with pooling
-            size set to pool_size. If 'None', no pooling will be added.
+        strides (int or tuple of 2 integers, optional): strides of the depthwise convolution.
+            Defaults to 1.
+        padding (str, optional): padding mode for the depthwise convolution. Defaults to 'same'.
+        use_bias (bool, optional): whether the layer uses a bias vector. Defaults to True.
+        pooling (str): add a pooling layer of type 'pooling' among the values 'max', or
+            'global_avg', with pooling size set to pool_size. If 'None', no pooling will be added.
+        post_relu_gap (bool): when pooling is 'global_avg', indicates if the pooling comes before or
+            after ReLU activation. Defaults to False.
         pool_size (int or tuple of 2 integers): factors by which to
             downscale (vertical, horizontal). (2, 2) will halve the input in
             both spatial dimension. If only one integer is specified, the same
             window length will be used for both dimensions.
         add_batchnorm (bool): add a BatchNormalization layer
         add_activation (bool): add a ReLU layer
-        **kwargs: arguments passed to the keras.SeparableConv2D layer,
-            such as strides, padding, use_bias, etc.
+        fused (bool): If True use a SeparableConv2D layer otherwise use a
+            DepthwiseConv2D + Conv2D layers. Defaults to True.
+        name (str, optional): name of the layer. Defaults to None.
+        kernel_initializer (keras.initializer, optional): initializer for both kernels. Defaults to
+            'glorot_uniform'.
+        pointwise_regularizer (keras.regularizers, optional): regularizer function applied to the
+            pointwise kernel matrix. Defaults to None.
 
     Returns:
         tf.Tensor: output tensor of separable conv block.
     """
-    if 'activation' in kwargs and kwargs['activation']:
-        raise ValueError("Keyword argument 'activation' in separable_conv_block must be None.")
-    if 'dilation_rate' in kwargs and kwargs['dilation_rate'] not in [1, [1, 1], (1, 1)]:
-        raise ValueError("Keyword argument 'dilation_rate' is not supported in "
-                         "separable_conv_block.")
-    if 'depth_multiplier' in kwargs and kwargs['depth_multiplier'] != 1:
-        raise ValueError("Keyword argument 'depth_multiplier' is not "
-                         "supported in separable_conv_block.")
+    if name:
+        dw_name = "dw_" + name
+        pw_name = "pw_" + name
 
-    sep_conv_layer = SeparableConv2D(filters, kernel_size, **kwargs)
-    x = sep_conv_layer(inputs)
+    else:
+        dw_name = pw_name = None
+    # if fused set a SeparableConv2D layer
+    if fused:
+        sep_conv_layer = SeparableConv2D(filters, kernel_size, strides=strides, padding=padding,
+                                         use_bias=use_bias,
+                                         depthwise_initializer=kernel_initializer,
+                                         pointwise_initializer=kernel_initializer,
+                                         pointwise_regularizer=pointwise_regularizer,
+                                         name=name)
+        x = sep_conv_layer(inputs)
+        main_layer_name = sep_conv_layer.name
+    # if not fused set a DepthwiseConv2D + Conv2D layer (the Conv2D applies a Pointwise convolution)
+    else:
+        depth_conv_layer = DepthwiseConv2D(kernel_size, strides=strides, padding=padding,
+                                           use_bias=False,
+                                           depthwise_initializer=kernel_initializer,
+                                           name=dw_name)
+        point_conv_layer = Conv2D(filters, (1, 1), use_bias=use_bias,
+                                  kernel_initializer=kernel_initializer,
+                                  kernel_regularizer=pointwise_regularizer,
+                                  name=pw_name)
 
-    if pooling:
-        x = _add_pooling_layer(x, pooling, pool_size, sep_conv_layer.padding,
-                               sep_conv_layer.name)
+        x = depth_conv_layer(inputs)
+        x = point_conv_layer(x)
+
+        main_layer_name = point_conv_layer.name
+
+    if pooling == 'max' or (pooling == 'global_avg' and not post_relu_gap):
+        x = _add_pooling_layer(x, pooling, pool_size, padding, main_layer_name)
 
     if add_batchnorm:
-        x = BatchNormalization(name=sep_conv_layer.name + '/BN')(x)
+        x = BatchNormalization(name=main_layer_name + '/BN')(x)
 
     if add_activation:
-        x = ReLU(6.0, name=sep_conv_layer.name + '/relu')(x)
+        x = ReLU(6.0, name=main_layer_name + '/relu')(x)
 
+    if post_relu_gap and pooling == 'global_avg':
+        x = _add_pooling_layer(x, pooling, pool_size, padding, main_layer_name)
     return x
 
 
@@ -425,44 +461,69 @@ def conv_transpose_block(inputs,
 def sepconv_transpose_block(inputs,
                             filters,
                             kernel_size,
+                            strides=2,
+                            padding='same',
+                            use_bias=True,
                             add_batchnorm=False,
                             add_activation=True,
-                            **kwargs):
+                            name=None,
+                            kernel_initializer='glorot_uniform',
+                            pointwise_regularizer=None):
     """Adds a transposed separable convolutional layer with optional layers in the following order:
     batch normalization, activation.
 
+    The separable operation is made of a DepthwiseConv2DTranspose followed by a pointwise Conv2D.
+
     Args:
         inputs (tf.Tensor): input tensor of shape `(rows, cols, channels)`
         filters (int): the dimensionality of the output space (i.e. the number of output filters in
             the pointwise convolution).
-        kernel_size (int or tuple of 2 integers): specifying the height and width of the 2D
-            convolution kernel. Can be a single integer to specify the same value for all spatial
+        kernel_size (int or tuple of 2 integers): specifying the height and width of the depthwise
+            transpose kernel. Can be a single integer to specify the same value for all spatial
             dimensions.
+        strides (int or tuple of 2 integers, optional): strides of the transposed depthwise.
+            Defaults to 2.
+        padding (str, optional): padding mode for the transposed depthwise. Defaults to 'same'.
+        use_bias (bool, optional): whether the layer uses a bias vectors. Defaults to True.
         add_batchnorm (bool, optional): add a BatchNormalization layer. Defaults to False.
         add_activation (bool, optional): add a ReLU8 layer. Defaults to True.
-        **kwargs: arguments passed to the SeparableConv2DTranspose layer, such as strides, padding,
-            use_bias, weight_regularizer, etc.
+        name (str, optional): name of the layer. Defaults to None.
+        kernel_initializer (keras.initializer, optional): initializer for both kernels. Defaults to
+            'glorot_uniform'.
+        pointwise_regularizer (keras.regularizers, optional): regularizer function applied to the
+            pointwise kernel matrix. Defaults to None.
 
     Returns:
         tf.Tensor: output tensor of transposed separable convolution block.
     """
-    if 'activation' in kwargs and kwargs['activation']:
-        raise ValueError("Keyword argument 'activation' in separable_conv_block must be None.")
-    if 'dilation_rate' in kwargs and kwargs['dilation_rate'] not in [1, [1, 1], (1, 1)]:
-        raise ValueError("Keyword argument 'dilation_rate' is not supported in "
-                         "separable_conv_block.")
-    if 'depth_multiplier' in kwargs and kwargs['depth_multiplier'] != 1:
-        raise ValueError("Keyword argument 'depth_multiplier' is not "
-                         "supported in separable_conv_block.")
+    if name:
+        dw_name = "dw_" + name
+        pw_name = "pw_" + name
+    else:
+        dw_name, pw_name = None, None
 
-    sepconv_trans_layer = SeparableConv2DTranspose(filters, kernel_size, **kwargs)
-    x = sepconv_trans_layer(inputs)
+    dw_trans_layer = DepthwiseConv2DTranspose(kernel_size,
+                                              strides=strides,
+                                              padding=padding,
+                                              use_bias=use_bias,
+                                              depthwise_initializer=kernel_initializer,
+                                              name=dw_name)
+    pw_layer = Conv2D(filters,
+                      kernel_size=1,
+                      padding='valid',
+                      use_bias=use_bias,
+                      kernel_regularizer=pointwise_regularizer,
+                      kernel_initializer=kernel_initializer,
+                      name=pw_name)
+
+    x = dw_trans_layer(inputs)
+    x = pw_layer(x)
 
     if add_batchnorm:
-        x = BatchNormalization(name=sepconv_trans_layer.name + '/BN')(x)
+        x = BatchNormalization(name=pw_layer.name + '/BN')(x)
 
     if add_activation:
-        x = ReLU(8.0, name=sepconv_trans_layer.name + '/relu')(x)
+        x = ReLU(8.0, name=pw_layer.name + '/relu')(x)
 
     return x
 
