@@ -26,7 +26,7 @@ from cnn2snn import quantize, load_quantized_model
 from ..layer_blocks import conv_block, dense_block
 from ..utils import fetch_file
 
-BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/gxnor/'
+BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/AkidaV1/gxnor/'
 
 
 def gxnor_mnist(weight_quantization=0,
@@ -113,26 +113,14 @@ def gxnor_mnist(weight_quantization=0,
 
 
 def gxnor_mnist_pretrained():
-    """ Helper method to retrieve a `gxnor_mnist` model that was trained on
-    MNIST dataset.
-
-    This model was trained with the distillation knowledge method, using
-    the EfficientNet model from `this repository
-    <https://github.com/EscVM/Efficient-CapsNet>`_ and the `Distiller` class from
-    the knowledge distillation toolkit (`akida_models.distiller`).
-
-    The float training was done for 30 epochs with a learning rate of 1e-4
-    After that we gradually quantize the model from:
-    8-4-4 --> 4-4-4 --> 4-4-2 --> 2-2-2 --> 2-2-1 tuning the model at each step
-    with the same distillation training method for 5 epochs and a learning rate
-    of 5e-5.
+    """ Helper method to retrieve a `gxnor_mnist` model that was trained on MNIST dataset.
 
     Returns:
         keras.Model: a Keras Model instance.
 
     """
     model_name = 'gxnor_mnist_iq2_wq2_aq1.h5'
-    file_hash = '836d4d32bf6a25620782f783419a1eae0c90460f3c291e2c5a8ed4a6cf36b035'
+    file_hash = 'f6f3e077c39fa4a65e401d3758af624fb276322e1d694fbf4f773941d43e7c5f'
     model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
                             fname=model_name,
                             file_hash=file_hash,
