@@ -199,11 +199,9 @@ def get_training_parser(batch_size,
             custom parameters. Defaults to None.
 
     Returns:
-        argparse.ArgumentParser, argparse.ArgumentParser,
-        argparse.ArgumentParser, argparse.ArgumentParser,
-        argparse.ArgumentParser,
-        argparse._SubParsersAction: main parser and train, calibrate, tune and eval actions
-            subparsers and the subparser object.
+        argparse.ArgumentParser, argparse.ArgumentParser, argparse.ArgumentParser,
+        argparse.ArgumentParser, argparse.ArgumentParser, argparse._SubParsersAction: main parser
+        and train, calibrate, tune and eval actions subparsers and the subparser object.
     """
 
     # Define a strictly positive int type for parameters
@@ -345,3 +343,21 @@ class RestoreBest(ModelCheckpoint):
             self.model.load_weights(self.filepath)
         # Clean temp directory
         self.temp_dir.cleanup()
+
+
+def save_model(model, model_path, save_path=None, action_str='saved'):
+    """ Saves the model with the given or a default name.
+
+    Args:
+        model (keras.Model): the model to save
+        model_path (str): the original model path
+        save_path (str): the path to save the model. Defaults to None.
+        action_str (str): the 'action' used in the training script, will be appended to the original
+            model path when save_path is None. Defaults to 'saved'.
+    """
+    if not save_path:
+        save_path = os.path.splitext(model_path)[0]
+        save_path += f"_{action_str}.h5"
+
+    model.save(save_path, include_optimizer=False)
+    print(f"Model saved as {save_path}.")
