@@ -21,10 +21,14 @@ Utilities for akida_models package.
 import os
 import urllib
 import time
+import numpy as np
+import warnings
+from pathlib import Path
 
 from six.moves.urllib.parse import urlsplit
 
 import tensorflow as tf
+import tensorflow_addons as tfa
 from keras.utils import io_utils
 from keras.utils.data_utils import validate_file, _extract_archive
 from keras.utils.generic_utils import Progbar
@@ -142,7 +146,7 @@ def load_model(model_path):
         model = load_quantized_model(model_path)
     except Exception:
         try:
-            model = qml_load_model(model_path)
+            model = qml_load_model(model_path, custom_layers={'GELU': tfa.layers.GELU})
         except Exception as e:
             raise e.__class__('Cannot load provided model.')
     return model
@@ -178,3 +182,70 @@ def get_tensorboard_callback(out_dir, histogram_freq=1, prefix=''):
                        update_freq='epoch',
                        write_graph=False,
                        profile_batch=0)
+
+
+def apply_weights_to_model(model, weights, verbose=True):
+    """Loads weights from a dictionary and apply it to a model.
+
+    Go through the dictionary of weights, find the corresponding variable
+    in the model and partially load its weights.
+
+    Args:
+        model (keras.Model): the model to update
+        weights (dict): the dictionary of weights
+        verbose (bool, optional): if True, throw warning messages if a dict
+        item is not found in the model. Defaults to True.
+    """
+    if len(weights) == 0:
+        warnings.warn("There is no weight to apply to the model.")
+        return
+
+    # Go through the dictionary of weights with each item
+    for key, value in weights.items():
+        value_applied = False
+        for dest_var in model.variables:
+            if key == dest_var.name:
+                # Apply the current item value
+                dest_var.assign(value)
+                value_applied = True
+                break
+        if not value_applied and verbose:
+            warnings.warn(f"Variable '{key}' not found in the model.")
+
+
+def load_weights(model, weights_path):
+    """Loads weights from a npz file and apply it to a model.
+
+    Go through the dictionary of weights of the npz file, find the
+    corresponding variable in the model and partially load its weights.
+
+    Args:
+        model (keras.Model): the model to update
+        weights_path (str): the path of the npz file to load
+    """
+    # Check the npz file validity
+    path = Path(weights_path)
+    if not path.is_file():
+        raise ValueError(f"File `{weights_path}` not found.")
+
+    # Open the npz file
+    weights_dict = np.load(weights_path)
+
+    # Apply the weights to the model
+    apply_weights_to_model(model, weights_dict)
+
+
+def save_weights(model, weights_path):
+    """Save model weights on an npz file.
+
+    Takes a model and save the weights of all its layers into an npz file.
+
+    Args:
+        model (keras.Model): the model to save its weights
+        weights_path (str): the path of the npz file to save
+    """
+    weights_dict = {}
+    for var in model.variables:
+        weights_dict[var.name] = var
+
+    np.savez(weights_path, **weights_dict)
