@@ -26,7 +26,7 @@ from cnn2snn import load_quantized_model, quantize
 from ..layer_blocks import conv_block, dense_block
 from ..utils import fetch_file
 
-BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
+BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/AkidaV1/vgg/'
 
 
 def vgg_utk_face(input_shape=(32, 32, 3),
