@@ -17,13 +17,15 @@
 """
 Training script for UTKFace model.
 """
+import os
 import numpy as np
 
 from keras.callbacks import LearningRateScheduler
 
 from cnn2snn import load_quantized_model, convert
 
-from ..training import get_training_parser, compile_model, evaluate_model, print_history_stats
+from ..training import (get_training_parser, compile_model, evaluate_model, print_history_stats,
+                        save_model)
 from .preprocessing import load_data
 
 
@@ -85,16 +87,13 @@ def main():
     # Load data
     x_train, y_train, x_test, y_test = get_data()
 
+    # Disable quantizeML assertions
+    os.environ["ASSERT_ENABLED"] = "0"
+
     # Train model
     if args.action == "train":
-        train_model(model, x_train, y_train, x_test, y_test, args.epochs,
-                    args.batch_size)
-
-        # Save model in Keras format (h5)
-        if args.savemodel:
-            model.save(args.savemodel, include_optimizer=False)
-            print(f"Trained model saved as {args.savemodel}")
-
+        train_model(model, x_train, y_train, x_test, y_test, args.epochs, args.batch_size)
+        save_model(model, args.model, args.savemodel, args.action)
     elif args.action == "eval":
         # Evaluate model accuracy
         if args.akida:
